@@ -7,6 +7,7 @@
 ** place of a destructor.
 *****************************************************************************/
 
+#include <qstyle.h>
 
 bool CurveAppearanceWidget::showLines()
 {
@@ -29,20 +30,35 @@ void CurveAppearanceWidget::init()
 
 void CurveAppearanceWidget::fillCombo()
 {
-  KstPoint tmppoint;
+    KstPoint tmppoint;
+    QRect rect;
+    int iCurrentItem;
+  
+    rect = _combo->style().querySubControlMetrics(
+           QStyle::CC_ComboBox, 
+           _combo, 
+           QStyle::SC_ComboBoxEditField );
+    rect.setLeft( rect.left() + 2 );
+    rect.setRight( rect.right() - 2 );
+    rect.setTop( rect.top() + 2 );
+    rect.setBottom( rect.bottom() - 2 );
+    
+    /* fill the point type dialog with point types */
+    QPixmap ppix( rect.width(), rect.height() );
+    QPainter pp( &ppix );
+  
+    iCurrentItem = _combo->currentItem( );
+    _combo->clear();
+    pp.setPen(color());
 
-  /* fill the point type dialog with point types */
-  QPixmap ppix(20,10);
-  QPainter pp(&ppix);
-  _combo->clear();
-  pp.setPen(color());
-
-  for (int ptype = 0; ptype <= KSTPOINT_MAXTYPE; ptype++) {
-    pp.fillRect(pp.window(), QColor("white"));
-    tmppoint.setType(ptype);
-    tmppoint.draw(&pp, ppix.width()/2, ppix.height()/2, 600);
-    _combo->insertItem(ppix);
-  }
+    for (int ptype = 0; ptype <= KSTPOINT_MAXTYPE; ptype++) {
+        pp.fillRect( pp.window(), QColor("white"));
+        tmppoint.setType(ptype);
+        tmppoint.draw( &pp, ppix.width()/2, ppix.height()/2, 600 );
+        _combo->insertItem(ppix);
+    }
+    
+    _combo->setCurrentItem( iCurrentItem );
 }
 
 
@@ -61,9 +77,9 @@ QColor CurveAppearanceWidget::color()
 
 void CurveAppearanceWidget::drawLine()
 {
-QPixmap pix(_label->contentsRect().size());
-QPainter p(&pix);
-KstPoint tmppoint;
+    QPixmap pix(_label->contentsRect().size());
+    QPainter p(&pix);
+    KstPoint tmppoint;
 
     p.fillRect(p.window(), QColor("white"));
     p.setPen(color());
@@ -130,3 +146,19 @@ void CurveAppearanceWidget::setUsePoints( bool usePoints )
 	drawLine();
     }
 }
+
+
+void CurveAppearanceWidget::setMustUseLines( bool bMustUseLines )
+{
+    _showLines->setEnabled(!bMustUseLines);
+    if (bMustUseLines && !_showLines->isChecked()) {
+	_showLines->setChecked(true);
+	drawLine();
+    }
+}
+
+
+void CurveAppearanceWidget::redrawCombo()
+{
+   fillCombo();
+}
