@@ -145,9 +145,9 @@ void FilterListEditor::applyToVectors()
 	if (cli->isOn()) {
 	    KstVectorPtr v = *KST::vectorList.findTag(cli->text(0));
 	    if (v) {
-		kdDebug() << "Creating a new filtered vector." << endl;
+		//kdDebug() << "Creating a new filtered vector." << endl;
 		KstFilteredVectorPtr fv = new KstFilteredVector(v, set);
-		kdDebug() << "Vector name is: " << fv->tagName() << endl;
+		//kdDebug() << "Vector name is: " << fv->tagName() << endl;
 	    }
 	}
     }
