@@ -18,7 +18,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-// include files for QT
+// include files for Qt
 #include <qdir.h>
 #include <qpainter.h>
 #include <qtimer.h>
@@ -40,31 +40,34 @@
 #include <kstatusbar.h>
 #include <kstdaction.h>
 
-#include <iostream>
-
 // application specific includes
+#include "datawizard.h"
+#include "debugdialog.h"
+#include "filterlisteditor.h"
 #include "kst.h"
-#include "kstview.h"
-#include "kstdoc.h"
-#include "kstextension.h"
-#include "kstplotdialog_i.h"
-#include "kstviewscalarsdialog_i.h"
 #include "kstchangefiledialog_i.h"
 #include "kstchangenptsdialog_i.h"
+#include "kstcurvedialog_i.h"
+#include "kstdatamanager_i.h"
+#include "kstdebug.h"
+#include "kstdoc.h"
+#include "ksteqdialog_i.h"
+#include "kstextension.h"
+#include "kstgraphfiledialog_i.h"
+#include "ksthsdialog_i.h"
+#include "kstiface_impl.h"
+#include "kstlabeldialog_i.h"
+#include "kstplotdialog_i.h"
+#include "kstplugindialog_i.h"
+#include "kstpsddialog_i.h"
 #include "kstquickcurvesdialog_i.h"
 #include "kstquickpsddialog_i.h"
-#include "kstgraphfiledialog_i.h"
-#include "kstvectordialog_i.h"
-#include "kstcurvedialog_i.h"
-#include "ksteqdialog_i.h"
-#include "ksthsdialog_i.h"
-#include "kstpsddialog_i.h"
-#include "kstplugindialog_i.h"
-#include "kstdatamanager_i.h"
-#include "kstlabeldialog_i.h"
-#include "kstiface_impl.h"
 #include "kstsettingsdlg.h"
-#include "filterlisteditor.h"
+#include "kstvectordialog_i.h"
+#include "kstview.h"
+#include "kstviewscalarsdialog_i.h"
+#include "kstviewvectorsdialog_i.h"
+#include "pluginmanager.h"
 #include "vectorsavedialog.h"
 
 #define KST_STATUSBAR_FRAME 0
@@ -84,10 +87,12 @@ KstApp::KstApp(QWidget *parent, const char* name)
   initView();
 
   /* create dialogs */
+  debugDialog = new DebugDialog(this);
   plotDialog = new KstPlotDialogI(doc, this);
   dataManager = new KstDataManagerI(doc, this);
   filterListEditor = new FilterListEditor(this);
-  //viewScalarsDialog = new KstViewScalarsDialogI(this);
+  viewScalarsDialog = new KstViewScalarsDialogI(this);
+  viewVectorsDialog = new KstViewVectorsDialogI(this);
   changeFileDialog = new KstChangeFileDialogI(this);
   changeNptsDialog = new KstChangeNptsDialogI(this);
   quickCurvesDialog = new KstQuickCurvesDialogI(this);
@@ -158,16 +163,12 @@ KstApp::KstApp(QWidget *parent, const char* name)
   KService::List sl = KServiceType::offers("Kst Extension");
   for (KService::List::ConstIterator it = sl.begin(); it != sl.end(); ++it) {
     KService::Ptr service = *it;
-    kdDebug() << "Found Kst Extension " << service->property("Name").toString() << endl;
     int err = 0;
     KstExtension *e = KParts::ComponentFactory::createInstanceFromService<KstExtension>(service, this, 0, QStringList(), &err);
     if (e) {
-      kdDebug() << "Kst Extension " << service->property("Name").toString() << " loaded" << endl;
+      KstDebug::self()->log(i18n("Kst Extension %1 loaded.").arg(service->property("Name").toString()));
     } else {
-      kdDebug() << "Error trying to load extension: " << err << endl;
-      if (err == KParts::ComponentFactory::ErrNoLibrary) {
-        kdDebug() << "Library error: " << KLibLoader::self()->lastErrorMessage() << endl;
-      }
+      KstDebug::self()->log(i18n("Error trying to load Kst extension %1.  Code=%2, \"%3\"").arg(service->property("Name").toString()).arg(err).arg(err == KParts::ComponentFactory::ErrNoLibrary ? i18n("Library not found.") : KLibLoader::self()->lastErrorMessage()), KstDebug::Error);
     }
   }
 }
@@ -349,7 +350,7 @@ void KstApp::initActions() {
                                      "to edit or create power spectra."));
 
   /************/
-  PluginDialogAction = new KAction(i18n("Edit Plugins"), 0, 0,
+  PluginDialogAction = new KAction(i18n("Edit &Plugins"), 0, 0,
                                    KstPluginDialogI::globalInstance(),
                                    SLOT(show_I()), actionCollection(),
                                    "plugindialog_action");
@@ -366,7 +367,6 @@ void KstApp::initActions() {
                                             "to change input files."));
 
   /************/
-#if 0
   ViewScalarsDialogAction = new KAction(i18n("View &Scalars"),
                                        0, 0, this,
                                        SLOT(showViewScalarsDialog()),
@@ -374,7 +374,15 @@ void KstApp::initActions() {
                                        "viewscalarsdialog_action");
   ViewScalarsDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
                                             "to view scalar values."));
-#endif
+  
+  /************/
+  ViewVectorsDialogAction = new KAction(i18n("View Vec&tors"),
+                                       0, 0, this,
+                                       SLOT(showViewVectorsDialog()),
+                                       actionCollection(),
+                                       "viewvectorsdialog_action");
+  ViewVectorsDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                            "to view vector values."));
   
   /************/
   ChangeNptsDialogAction = new KAction(i18n("Change Data Sample &Ranges"),
@@ -457,13 +465,29 @@ void KstApp::initActions() {
   SamplesFromEndAction->setWhatsThis(i18n("Read current data from end of file."));
 
   /************/
-  PluginManagerAction = new KAction(i18n("&Plugins"), 0, 0,
+  PluginManagerAction = new KAction(i18n("&Plugins..."), 0, 0,
                                  this, SLOT(showPluginManager()),
                                  actionCollection(), "pluginmanager_action");
   PluginManagerAction->setWhatsThis(i18n("Bring up a dialog box\n"
                                            "to manage plugins."));
 
 
+  /************/
+  DataWizardAction = new KAction(i18n("Data &Wizard..."), "kst_datawizard", 0,
+                                 this, SLOT(showDataWizard()),
+                                 actionCollection(), "datawizard_action");
+  DataWizardAction->setWhatsThis(i18n("Bring up a wizard\n"
+                                           "to easily load data."));
+
+
+  /************/
+  DebugDialogAction = new KAction(i18n("Debug Kst..."), 0, 0,
+                                 debugDialog, SLOT(show()),
+                                 actionCollection(), "debug_action");
+  DebugDialogAction->setWhatsThis(i18n("Bring up a dialog\n"
+                                           "to display debugging information."));
+
+
   /************/
   DataMode = new KToggleAction(i18n("Data Mode"), "kst_datamode", 0,
                                  this, SLOT(toggleDataMode()),
@@ -836,7 +860,11 @@ void KstApp::showDataManager() {
 }
 
 void KstApp::showViewScalarsDialog() {
-  //viewScalarsDialog->showViewScalarsDialog();
+  viewScalarsDialog->showViewScalarsDialog();
+}
+
+void KstApp::showViewVectorsDialog() {
+  viewVectorsDialog->showViewVectorsDialog();
 }
 
 void KstApp::showChangeFileDialog() {
@@ -893,18 +921,17 @@ void KstApp::updateDialogs() {
   quickPSDDialog->update();
   dataManager->update();
   filterListEditor->update();
-#if 0
   if (!viewScalarsDialog->isHidden()) {
     viewScalarsDialog->updateViewScalarsDialog();
   }
-#endif
+  if (!viewVectorsDialog->isHidden()) {
+    viewVectorsDialog->updateViewVectorsDialog();
+  }
   vectorSaveDialog->init();
   view->update();
 }
 
 
-#include "pluginmanager.h"
-
 void KstApp::showPluginManager() {
   PluginManager *pm = new PluginManager(this, "Plugin Manager");
   pm->exec();
@@ -914,6 +941,20 @@ void KstApp::showPluginManager() {
 }
 
 
+void KstApp::showDataWizard() {
+  DataWizard *dw = new DataWizard(this, "DataWizard");
+  dw->exec();
+  if (dw->result() == QDialog::Accepted) {
+    delete dw; // leave this here - releases references
+    doc->update();
+    doc->setModified();
+    doc->updateDialogs();
+  } else {
+    delete dw;
+  }
+}
+
+
 void KstApp::registerDocChange() {
   doc->update();
   doc->setModified();
