@@ -68,8 +68,8 @@ void KstChangeFileDialogI::updateChangeFileDialog() {
   }
 
   /* insert file names into ChangeFileName list */
-  for (i = 0; i < (int)KST::fileList.count(); i++) {
-    ChangeFileName->insertItem(KST::fileList[i]->fileName());
+  for (i = 0; i < (int)KST::dataSourceList.count(); i++) {
+    ChangeFileName->insertItem(KST::dataSourceList[i]->fileName());
   }
 }
 
@@ -92,35 +92,37 @@ void KstChangeFileDialogI::browseFile() {
 }
 
 void KstChangeFileDialogI::applyFileChange() {
-  int i_vector;
-  KstFilePtr file;
+  KstDataSourcePtr file;
   KstRVectorPtr vector;
 
   /* if there is not an active KstFile, create one */
-  KstFileList::Iterator it;
-  for (it = KST::fileList.begin(); it != KST::fileList.end(); ++it) {
+  KstDataSourceList::Iterator it;
+  for (it = KST::dataSourceList.begin(); it != KST::dataSourceList.end(); ++it) {
     if ((*it)->fileName() == ChangeFileName->currentText()) {
       file = *it;
       break;
     }
   }
 
-  if (it == KST::fileList.end()) {
-    file = new KstFile(ChangeFileName->currentText());
-    if (file->numFrames() < 1) { // No data in file
-      KMessageBox::sorry(0L, i18n("%1: The requested file does not contain data. Operation canceled.").arg(ChangeFileName->currentText()));
-      delete file;
+  if (it == KST::dataSourceList.end()) {
+    file = KstDataSource::loadSource(ChangeFileName->currentText());
+    if (!file || !file->isValid()) {
+      KMessageBox::sorry(0L, i18n("%1: Unable to open file.").arg(ChangeFileName->currentText()));
       return;
     }
-    KST::fileList.append(file);
+    if (file->frameCount() < 1) {
+      KMessageBox::sorry(0L, i18n("%1: File does not contain data. Operation canceled.").arg(ChangeFileName->currentText()));
+      return;
+    }
+    KST::dataSourceList.append(file);
   }
 
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
-  for (i_vector = 0; i_vector < (int)ChangeFileCurveList->count(); i_vector++) {
-    if (ChangeFileCurveList->isSelected(i_vector)) {
-      vector = rvl[i_vector];
+  for (int i = 0; i < (int)ChangeFileCurveList->count(); i++) {
+    if (ChangeFileCurveList->isSelected(i)) {
+      vector = rvl[i];
       if (!file->isValidField(vector->getField())) {
-        KMessageBox::sorry(0L, i18n("%1: The requested field is not defined for the requested file.").arg(vector->getField()));
+        KMessageBox::sorry(0L, i18n("%1: Field is not defined for the requested file.").arg(vector->getField()));
       } else {
         vector->changeFile(file);
       }
