@@ -57,10 +57,10 @@ KstCurveDialogI::KstCurveDialogI(QWidget* parent,
   connect(New, SIGNAL(clicked()), this, SLOT(new_I()));
   connect(Edit, SIGNAL(clicked()), this, SLOT(edit_I()));
   connect(Delete, SIGNAL(clicked()), this, SLOT(delete_I()));
-  connect(_xVector, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
-  connect(_yVector, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
-  connect(_xError, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
-  connect(_yError, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
+  connect(_xVector, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
+  connect(_yVector, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
+  connect(_xError, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
+  connect(_yError, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
   _xError->provideNoneVector(true);
   _yError->provideNoneVector(true);
 }
