@@ -23,37 +23,41 @@
 
 #include <qfile.h>
 
-bool KST::dataTagNameNotUnique(const QString &tag, bool warn) {
+bool KST::dataTagNameNotUnique(const QString &tag, bool warn, void *p) {
   /* verify that the tag name is not empty */
   if (tag.stripWhiteSpace().isEmpty()) {
-      if (warn)
-        KMessageBox::sorry(0L, i18n("Empty tag names are not allowed."));
+      if (warn) {
+        KMessageBox::sorry(static_cast<QWidget*>(p), i18n("Empty tag names are not allowed."));
+      }
       return true;
   }
 
   /* verify that the tag name is not used by a data object */
   if (KST::dataObjectList.findTag(tag) != KST::dataObjectList.end()) {
-      if (warn)
-        KMessageBox::sorry(0L, i18n("%1: this name is already in use. Change it to a unique name.").arg(tag));
+      if (warn) {
+        KMessageBox::sorry(static_cast<QWidget*>(p), i18n("%1: this name is already in use. Change it to a unique name.").arg(tag));
+      }
       return true;
   }
 
   return false;
 }
 
-bool KST::vectorTagNameNotUnique(const QString &tag, bool warn) {
+bool KST::vectorTagNameNotUnique(const QString &tag, bool warn, void *p) {
   /* verify that the tag name is not empty */
   if (tag.stripWhiteSpace().isEmpty()) {
-      if (warn)
-        KMessageBox::sorry(0L, i18n("Empty tag names are not allowed."));
+      if (warn) {
+        KMessageBox::sorry(static_cast<QWidget*>(p), i18n("Empty tag names are not allowed."));
+      }
       return true;
   }
 
   /* verify that the tag name is not used by a data object */
   if (KST::vectorList.findTag(tag) != KST::vectorList.end() ||
       KST::scalarList.findTag(tag) != KST::scalarList.end()) {
-      if (warn)
-        KMessageBox::sorry(0L, i18n("%1: this name is already in use. Change it to a unique name.").arg(tag));
+      if (warn) {
+        KMessageBox::sorry(static_cast<QWidget*>(p), i18n("%1: this name is already in use. Change it to a unique name.").arg(tag));
+      }
       return true;
   }
 
@@ -61,14 +65,14 @@ bool KST::vectorTagNameNotUnique(const QString &tag, bool warn) {
 }
 
 
-int KST::vectorToFile(KstVectorPtr v, QFile *f) {
-int rc = 0;
+int KST::vectorToFile(KstVectorPtr v, QFile *f, void *p) {
+  int rc = 0;
 #define BSIZE 128
-char buf[BSIZE];
-int _size = v->length();
-double *_v = v->value();
-register int modval;
-KProgressDialog *kpd = new KProgressDialog(0L, "vector save", i18n("Saving Vector"), i18n("Saving vector %1...").arg(v->tagName()));
+  char buf[BSIZE];
+  int _size = v->length();
+  double *_v = v->value();
+  register int modval;
+  KProgressDialog *kpd = new KProgressDialog(static_cast<QWidget*>(p), "vector save", i18n("Saving Vector"), i18n("Saving vector %1...").arg(v->tagName()));
 
   kpd->setAllowCancel(false);
 
@@ -87,10 +91,10 @@ KProgressDialog *kpd = new KProgressDialog(0L, "vector save", i18n("Saving Vecto
   }
   kpd->progressBar()->setProgress(_size);
 
-delete kpd;
+  delete kpd;
 
 #undef BSIZE
-return rc;
+  return rc;
 }
 
-
+// vim: ts=2 sw=2 et
