@@ -21,12 +21,14 @@
 
 #include <kdebug.h>
 #include <klibloader.h>
+#include <klocale.h>
 #include <kservice.h>
 #include <kservicetype.h>
 
 #include <qfile.h>
 #include <qstylesheet.h>
 
+#include "kstdebug.h"
 #include "stdinsource.h"
 
 
@@ -45,7 +47,9 @@ namespace KST {
       KstDataSource *create(const QString& filename, const QString& type = QString::null) const {
         KstDataSource *(*sym)(const QString&, const QString&) = (KstDataSource*(*)(const QString&, const QString&))symbol("create");
         if (sym) {
-          return (sym)(filename, type);
+          KstDataSource *ds = (sym)(filename, type);
+          ds->_source = service->property("Name").toString();
+          return ds;
         }
 
         return 0L;
@@ -91,8 +95,7 @@ namespace KST {
         QCString libname = QFile::encodeName(QString("kstdata_") + _plugLib);
         _lib = KLibLoader::self()->library(libname);
         if (!_lib) {
-          kdDebug() << "Error datasource plugin [" << libname << "]" << endl;
-          kdDebug() << "Reason: " << KLibLoader::self()->lastErrorMessage() << endl;
+          KstDebug::self()->log(i18n("Error loading data source plugin [%1]: %2").arg(libname).arg(KLibLoader::self()->lastErrorMessage()), KstDebug::Error);
         }
         return _lib != 0L;
       }
@@ -114,7 +117,7 @@ static KST::PluginInfoList pluginInfo;
 static void scanPlugins() {
   KST::PluginInfoList tmpList;
 
-  kdDebug() << "Scanning for plugins..." << endl;
+  KstDebug::self()->log(i18n("Scanning for data source plugins."));
 
   KService::List sl = KServiceType::offers("Kst Data Source");
   for (KService::List::ConstIterator it = sl.begin(); it != sl.end(); ++it) {
@@ -126,15 +129,27 @@ static void scanPlugins() {
     }
 
     KSharedPtr<KST::Plugin> p = new KST::Plugin(*it);
-    kdDebug() << "Added a new plugin " << (*it)->property("Name").toString() << endl;
     tmpList.append(p);
   }
 
   // This cleans up plugins that have been uninstalled and adds in new ones.
   // Since it is a shared pointer it can't dangle anywhere.
   pluginInfo = tmpList;
+}
 
-  kdDebug() << "Done scanning for plugins!" << endl;
+
+QStringList KstDataSource::pluginList() {
+  QStringList rc;
+
+  if (pluginInfo.isEmpty()) {
+    scanPlugins();
+  }
+
+  for (KST::PluginInfoList::ConstIterator it = pluginInfo.begin(); it != pluginInfo.end(); ++it) {
+    rc += (*it)->service->property("Name").toString();
+  }
+
+  return rc;
 }
 
 
@@ -277,12 +292,6 @@ void KstDataSource::save(QTextStream &ts) {
 }
 
 
-int KstDataSource::readIFile() {
-  // FIXME
-  return -1;
-}
-
-
 void KstDataSource::virtual_hook(int id, void *data) {
   Q_UNUSED(id)
   Q_UNUSED(data)
