@@ -52,6 +52,7 @@
 // application specific includes
 #include "kst.h"
 #include "kstdatacollection.h"
+#include "kstdebug.h"
 #include "kstdoc.h"
 #include "kstequationcurve.h"
 #include "kstfilteredvector.h"
@@ -208,8 +209,7 @@ bool KstDoc::openDocument(const KURL &url, const QString &o_file,
           file = KstDataSource::loadSource(o_file);
         }
         if (file && (!file->isValid() || file->frameCount() < 1)) {
-          kdWarning() << QString("No data in file: %1").arg(file->fileName())
-                      << endl;
+          KstDebug::self()->log(i18n("No data in file %1.").arg(file->fileName()), KstDebug::Warning);
         }
         if (file) {
           KST::dataSourceList.append(file);
@@ -238,7 +238,7 @@ bool KstDoc::openDocument(const KURL &url, const QString &o_file,
         KstBaseCurveList l = kstObjectSubList<KstDataObject,KstBaseCurve>(KST::dataObjectList);
         KST::plotList.append(new KstPlot(e, l));
       } else {
-        kdWarning() << QString("unsupported element: %1").arg(e.tagName()) << endl;
+        KstDebug::self()->log(i18n("Unsupported element '%1' in file %2.").arg(e.tagName()).arg(file->fileName()), KstDebug::Warning);
       }
     }
     n = n.nextSibling();
