@@ -56,8 +56,8 @@ KstEqDialogI::KstEqDialogI(QWidget* parent, const char* name, bool modal, WFlags
   connect(New, SIGNAL(clicked()), this, SLOT(new_I()));
   connect(Edit, SIGNAL(clicked()), this, SLOT(edit_I()));
   connect(Delete, SIGNAL(clicked()), this, SLOT(delete_I()));
-  connect(_vectors, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
-  connect(_xVectors, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
+  connect(_vectors, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
+  connect(_xVectors, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
   connect(_scalars, SIGNAL(newScalarCreated()), this, SIGNAL(modified()));
 }
 
