@@ -56,7 +56,7 @@ KstHsDialogI::KstHsDialogI(QWidget* parent, const char* name, bool modal, WFlags
   connect(Edit, SIGNAL(clicked()), this, SLOT(edit_I()));
   connect(Delete, SIGNAL(clicked()), this, SLOT(delete_I()));
   connect(AutoBin, SIGNAL(clicked()), this, SLOT(autoBin()));
-  connect(_vector, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
+  connect(_vector, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
   _curveAppearance->setUsePoints(false);
   _curveAppearance->setMustUseLines(true);
 }
