@@ -208,6 +208,12 @@ void KstMouse::setCursor(bool in_plot, const QMouseEvent *e) {
       setMode(LABEL_TOOL);
       return;
     }
+    
+    if (getLegend(e)) {
+      _view->setCursor(*ArrowCursor);
+      setMode(LABEL_TOOL);
+      return;      
+    }
   }
 
   setCursor(in_plot, e->state());
@@ -242,10 +248,10 @@ int KstMouse::getLabelNum(const QMouseEvent *e) {
   KstPlot *plot = KST::plotList.at(getPlotNum());
   if (plot) {
     QPoint pt = plot->GetWinRegion().topLeft();
-    int x = e->x() - pt.x(), y = e->y() - pt.y();
-
+    QPoint ptCheck( e->x() - pt.x(), e->y() - pt.y() );
+    
     for(unsigned i = 0; i < plot->labelList.count(); i++) {
-      if (plot->labelList.at(i)->extents.contains(x, y)) {
+      if (plot->labelList.at(i)->extents.contains(ptCheck)) {
         return i;
       }
     }
@@ -254,4 +260,17 @@ int KstMouse::getLabelNum(const QMouseEvent *e) {
   return -1;
 }
 
+bool KstMouse::getLegend(const QMouseEvent *e) {
+  KstPlot *plot = KST::plotList.at(getPlotNum());
+  if (plot) {
+    QPoint pt = plot->GetWinRegion().topLeft();
+    QPoint ptCheck( e->x() - pt.x(), e->y() - pt.y() );
+    
+    if (plot->Legend->extents.contains(ptCheck)) {
+      return true;
+    }
+  }
+
+  return false;
+}
 // vim: ts=2 sw=2 et
