@@ -82,28 +82,23 @@ KstPlot::KstPlot(QDomElement &e, KstBaseCurveList &in_curveList) {
       } else if (e.tagName() == "ymax") {
         ymax_in = e.text().toDouble();
       } else if (e.tagName() == "toplabel") {
-        if (in_toplabel)
-          delete in_toplabel;
+        delete in_toplabel;
         in_toplabel = new KstLabel(" ");
         in_toplabel->read(e);
       } else if (e.tagName() == "xlabel") {
-        if (in_xlabel)
-          delete in_xlabel;
+        delete in_xlabel;
         in_xlabel = new KstLabel(" ");
         in_xlabel->read(e);
       } else if (e.tagName() == "ylabel") {
-        if (in_ylabel)
-          delete in_ylabel;
+        delete in_ylabel;
         in_ylabel = new KstLabel(" ");
         in_ylabel->read(e);
       } else if (e.tagName() == "ticklabel") {
-        if (in_ticklabel)
-          delete in_ticklabel;
+        delete in_ticklabel;
         in_ticklabel = new KstLabel(" ");
         in_ticklabel->read(e);
       } else if (e.tagName() == "legend") {
-        if (in_legend)
-          delete in_legend;
+        delete in_legend;
         in_legend = new KstLegend();
         in_legend->read(e);
       } else if (e.tagName() == "label") {
@@ -1557,6 +1552,8 @@ void KstPlot::pushScale() {
   ps->ymax = YMax;
   ps->xscalemode = XScaleMode;
   ps->yscalemode = YScaleMode;
+  ps->xlog = XLog;
+  ps->ylog = YLog;
 
   PlotScaleList.append(ps);
 }
@@ -1573,6 +1570,8 @@ bool KstPlot::popScale() {
     YMax = ps->ymax;
     XScaleMode = ps->xscalemode;
     YScaleMode = ps->yscalemode;
+    XLog = ps->xlog;
+    YLog = ps->ylog;
     return true;
   }
   return false;
