@@ -40,8 +40,9 @@
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 
-#include "kstlegend.h"
 #include "kstdatacollection.h"
+#include "kstdebug.h"
+#include "kstlegend.h"
 #include "kstplotdialog_i.h"
 #include "kstsettings.h"
 
@@ -448,7 +449,7 @@ void KstPlotDialogI::applyLimits(KstPlot *plot) {
   } else if (XNoSpikes->isChecked()) {
     plot->setXScaleMode(NOSPIKE);
   } else {
-    kdDebug() << "Bug in kst: no x scale type checked (?!!)" << endl;
+    KstDebug::self()->log(i18n("Internal error: No X scale type checked in %1.").arg(Select->currentText()), KstDebug::Error);
   }
 
     /* do Y Scale */
@@ -465,7 +466,7 @@ void KstPlotDialogI::applyLimits(KstPlot *plot) {
   } else if (YNoSpikes->isChecked()) {
     plot->setYScaleMode(NOSPIKE);
   } else {
-    kdDebug() << "Bug in kst: no y scale type checked (?!!)" << endl;
+    KstDebug::self()->log(i18n("Internal error: No Y scale type checked in %1.").arg(Select->currentText()), KstDebug::Error);
   }
 
   plot->setLog(XIsLog->isChecked(), YIsLog->isChecked());
