@@ -41,7 +41,8 @@ public:
 public slots:
   /** Update info in the plot dialog */
   void update(int new_index = -1);
-
+  void newTab();
+  
   /** Calls update(), then shows/raises the dialog */
   void show_I();
   void new_I();
@@ -54,7 +55,8 @@ public slots:
   void updateSampXLabel();
   void updateSampYLabel();
   void updateLabels();
-
+  void updateSampLegendLabel();
+  
   void setScalarDestTopLabel() {ScalarDest = TopLabelText;}
   void setScalarDestXLabel() {ScalarDest = XAxisText;}
   void setScalarDestYLabel() {ScalarDest = YAxisText;}
