@@ -15,14 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "plugincollection.h"
-#include "kstplugin.h"
-#include "kstdoc.h"
 #include "kstdatacollection.h"
+#include "kstdebug.h"
+#include "kstdoc.h"
+#include "kstplugin.h"
 #include "kstplugindialog_i.h"
+#include "plugincollection.h"
+
 #include <kdebug.h>
-#include <kmessagebox.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 
 #include <stdlib.h>
 
@@ -83,9 +85,7 @@ KstPlugin::KstPlugin(QDomElement &e) : KstDataObject(e) {
   _plugin = PluginCollection::self()->plugin(pluginName);
 
   if (!_plugin.data()) {
-    kdWarning() << i18n("Unable to load plugin %1 for \"%2\".").arg(pluginName).arg(tagName()) << endl;
-    // can cause nasty crashes
-    //KMessageBox::sorry(0L, i18n("Unable to load plugin %1 for \"%2\".").arg(pluginName).arg(tagName()));
+    KstDebug::self()->log(i18n("Unable to load plugin %1 for \"%2\".").arg(pluginName).arg(tagName()), KstDebug::Warning);
   } else {
     countScalarsAndVectors(_plugin->data()._inputs, _inScalarCnt, _inArrayCnt);
 
@@ -177,7 +177,7 @@ KstObject::UpdateType KstPlugin::update(int update_counter) {
                                                                         ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
       if (!_inputVectors.contains((*it)._name)) {
-        kdWarning() << "Plugin [" << tagName() << "]: Input vector " << (*it)._name << " not found.  Cannot continue." << endl;
+        KstDebug::self()->log(i18n("Input vector [%1] for plugin %2 not found.  Unable to continue.").arg((*it)._name).arg(tagName()), KstDebug::Error);
         CLEANUP();
         return NO_CHANGE;
       }
@@ -195,7 +195,7 @@ KstObject::UpdateType KstPlugin::update(int update_counter) {
                                                                         ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
       if (!_outputVectors.contains((*it)._name)) {
-        kdWarning() << "Plugin [" << tagName() << "]: Output vector " << (*it)._name << " not found.  Cannot continue." << endl;
+        KstDebug::self()->log(i18n("Output vector [%1] for plugin %2 not found.  Unable to continue.").arg((*it)._name).arg(tagName()), KstDebug::Error);
         CLEANUP();
         return NO_CHANGE;
       }
@@ -288,8 +288,6 @@ QString KstPlugin::propertyString() const {
 
 
 bool KstPlugin::setPlugin(KSharedPtr<Plugin> plugin) {
-  kdDebug() << "KstPlugin::setPlugin" << endl;
-
   if (plugin == _plugin) {
     return true;
   }
