@@ -144,7 +144,7 @@ void KstPluginDialogI::update(int new_index) {
   QString selectedScalar;
   int oldSelect = Select->currentItem();
   int oldCount = Select->count();
-  
+
   KstPluginList pl = kstObjectSubList<KstDataObject, KstPlugin>(KST::dataObjectList);
 
   Select->clear();
@@ -152,7 +152,7 @@ void KstPluginDialogI::update(int new_index) {
   for (KstPluginList::iterator it = pl.begin(); it != pl.end(); ++it) {
     Select->insertItem((*it)->tagName());
   }
-  
+
   if (new_index == -2 || Select->count() == 0) {
     Select->insertItem(i18n("P%1-%2").arg(Select->count()+1).arg(newPluginString));
     Select->setCurrentItem(Select->count()-1);
@@ -183,7 +183,7 @@ void KstPluginDialogI::update(int new_index) {
   }
 
   KSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[PluginCombo->currentItem()]);
-  if( pPtr != 0 ) {  
+  if( pPtr != 0 ) {
     // Update input vector and scalar combos
     const QValueList<Plugin::Data::IOValue>& itable = pPtr->data()._inputs;
     for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin(); it != itable.end(); ++it) {
@@ -212,7 +212,7 @@ void KstPluginDialogI::update(int new_index) {
             ss->update();
           }
           if (plugin.data() && plugin->isValid()) {
-            ss->setSelection(plugin->inputScalars()[(*it)._name]->tagName());            
+            ss->setSelection(plugin->inputScalars()[(*it)._name]->tagName());
           } else {
             ss->setSelection(selectedScalar);
           }
@@ -229,11 +229,13 @@ void KstPluginDialogI::update(int new_index) {
         assert(field);
         if (field) {
           QLineEdit *li = static_cast<QLineEdit*>(field);
+          QString ts;
           if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
-            li->setText(plugin->outputVectors()[(*it)._name]->tagName());
+            ts = plugin->outputVectors()[(*it)._name]->tagName();
           } else { // scalar
-            li->setText(plugin->outputScalars()[(*it)._name]->tagName());
+            ts = plugin->outputScalars()[(*it)._name]->tagName();
           }
+          li->setText(ts);
         }
       }
     }
@@ -283,6 +285,7 @@ return true;
 
 bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KSharedPtr<Plugin> p) {
   const QValueList<Plugin::Data::IOValue>& otable = p->data()._outputs;
+
   for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
     QObject *field = _frameWidget->child((*it)._name.latin1(), "QLineEdit");
     assert(field);
@@ -290,8 +293,11 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KSharedPtr<Plugin> p) {
     QLineEdit *li = static_cast<QLineEdit*>(field);
 
     if (li->text().isEmpty()) {
-      KMessageBox::sorry(this, i18n("The field %1 is empty.  Not saving.").arg((*it)._name));
-      return false;
+      QString tagName = Select->currentText();
+      if (tagName.endsWith(newPluginString)) {
+        tagName = plugin->tagName();
+      }
+      li->setText(tagName+"-"+(*it)._name);
     }
 
     QString nt = li->text();
@@ -312,7 +318,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KSharedPtr<Plugin> p) {
             nt += "'";
           }
           plugin->outputScalars()[(*it)._name]->setTagName(nt);
-      } 
+      }
     }
   }
 
@@ -340,10 +346,6 @@ void KstPluginDialogI::new_I() {
 
       plugin->setPlugin(pPtr);
 
-      if (!saveOutputs(plugin, pPtr)) {
-        return;
-      }
-
       if (tagName.endsWith(newPluginString)) {
         QString tmpTagName;
         int i = 0;
@@ -353,9 +355,12 @@ void KstPluginDialogI::new_I() {
         tagName = tmpTagName;
       }
       plugin->setTagName(tagName);
+      if (!saveOutputs(plugin, pPtr)) {
+        return;
+      }
     }
   }
-  
+
   if (!plugin || !plugin->isValid()) {
     KMessageBox::sorry(this, i18n("There is an error in the plugin you entered. Please fix it."));
     return;
@@ -496,7 +501,7 @@ QString scalarLabelTemplate, vectorLabelTemplate;
         }
       } else {
         widget = new VectorSelector(parent, (*it)._name.latin1());
-        connect(widget, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
+        connect(widget, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
       }
     } else {
       widget = new QLineEdit(parent, (*it)._name.latin1());
