@@ -110,7 +110,7 @@ void KstPSDCurve::commonConstructor(const QString &in_tag, KstVectorPtr in_V,
   NumUsed = 0;
   _inputVectors[INVECTOR] = in_V;
   Color = in_color;
-  _tag = in_tag;
+  setTagName(in_tag);
   Freq = in_freq;
   Len = in_len;
   VUnits = in_VUnits;
@@ -129,10 +129,10 @@ void KstPSDCurve::commonConstructor(const QString &in_tag, KstVectorPtr in_V,
   setRemoveMean(true);
   setAppodize(true);
 
-  KstVectorPtr iv = new KstVector(_tag+"-freq", 2);
+  KstVectorPtr iv = new KstVector(in_tag+"-freq", 2);
   _fVector = _outputVectors.insert(FVECTOR, iv);
 
-  iv = new KstVector(_tag+"-sv", PSDLen);
+  iv = new KstVector(in_tag+"-sv", PSDLen);
   _sVector = _outputVectors.insert(SVECTOR, iv);
 
   update();
@@ -305,7 +305,7 @@ void KstPSDCurve::getPoint(int i, double &x, double &y) {
 
 void KstPSDCurve::save(QTextStream &ts) {
   ts << " <psd>" << endl;
-  ts << "  <tag>" << _tag << "</tag>" << endl;
+  ts << "  <tag>" << tagName() << "</tag>" << endl;
   ts << "  <vectag>" << _inputVectors[INVECTOR]->tagName() << "</vectag>" << endl;
 
   ts << "  <color>" << Color.name() << "</color>" << endl;
