@@ -54,7 +54,7 @@ KstPsdDialogI::KstPsdDialogI(QWidget* parent, const char* name, bool modal, WFla
   connect(New,    SIGNAL(clicked()), this, SLOT(new_I()));
   connect(Edit,   SIGNAL(clicked()), this, SLOT(edit_I()));
   connect(Delete, SIGNAL(clicked()), this, SLOT(delete_I()));
-  connect(_vector, SIGNAL(newVectorCreated()), this, SIGNAL(modified()));
+  connect(_vector, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
 }
 
 KstPsdDialogI::~KstPsdDialogI() {
