@@ -16,13 +16,16 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdlib.h>
-#include <stdio.h>
 #include <math.h>
-#include <klocale.h>
+#include <stdio.h>
+#include <stdlib.h>
+
 #include <kdebug.h>
-#include "kstrvector.h"
+#include <klocale.h>
+
 #include "kstdatacollection.h"
+#include "kstdebug.h"
+#include "kstrvector.h"
 
 /** Create a KstRVector: raw data from a file */
 KstRVector::KstRVector(KstDataSourcePtr in_file, const QString &in_field,
@@ -134,6 +137,10 @@ void KstRVector::commonRVConstructor(KstDataSourcePtr in_file,
 
   _dirty = true;
 
+  if (!in_file) {
+    KstDebug::self()->log(i18n("Data file for vector %1 was not opened.").arg(tagName()), KstDebug::Warning);
+  }
+
   update(-1);
 }
 
@@ -165,6 +172,9 @@ void KstRVector::change(KstDataSourcePtr in_file, const QString &in_field,
 }
 
 void KstRVector::changeFile(KstDataSourcePtr in_file) {
+  if (!in_file) {
+    KstDebug::self()->log(i18n("Data file for vector %1 was not opened.").arg(tagName()), KstDebug::Warning);
+  }
   _file = in_file;
   reset();
 }
