@@ -20,6 +20,8 @@
 #include "kstdoc.h"
 #include <klocale.h>
 
+#include <qstylesheet.h>
+
 /** Create the base scalar */
 KstScalar::KstScalar(const QString& in_tag, double val) : KstObject(), _orphan(false) {
   QString _tag = in_tag;
@@ -70,7 +72,7 @@ KstObject::UpdateType KstScalar::update(int updateCounter) {
 
 
 void KstScalar::save(QTextStream &ts) {
-  ts << "    <tag>" << tagName() << "</tag>" << endl;
+  ts << "    <tag>" << QStyleSheet::escape(tagName()) << "</tag>" << endl;
   ts << "    <value>" << value() << "</value>" << endl;
 }
 
