@@ -58,6 +58,7 @@ KstVectorDialogI::KstVectorDialogI(QWidget* parent, const char* name,
 
     FileName->setMode(KFile::File | KFile::Directory | KFile::ExistingOnly
                       | KFile::LocalOnly);
+    connect(FileName, SIGNAL(textChanged(const QString&)), this, SLOT(updateCompletion()));
     _fieldCompletion = Field->completionObject();
     Field->setAutoDeleteCompletionObject( true );
 //     connect(Field,SIGNAL(returnPressed(const QString&)),
@@ -68,6 +69,26 @@ KstVectorDialogI::~KstVectorDialogI() {
 
 }
 
+void KstVectorDialogI::updateCompletion() {
+  Field->clear();
+
+  /* update filename list and fill axes combo boxes */
+  KstDataSourcePtr ds = *KST::dataSourceList.findFileName(FileName->url());
+  if (!ds && FileName->url() != "stdin") {
+    ds = KstDataSource::loadSource(FileName->url());
+    if (ds) { // FIXME we should eventually make KstDataSource::loadFieldList()
+      KST::dataSourceList.append(ds);
+    }
+  }
+
+  if (ds) {
+    Field->insertStringList(ds->fieldList());
+    _fieldCompletion->insertItems(ds->fieldList());
+  }
+
+  Field->setCurrentText(QString::null);
+}
+
 void KstVectorDialogI::show_I() {
   update();
   show();
@@ -215,7 +236,7 @@ void KstVectorDialogI::new_I() {
   tag_name.replace(i18n("<New_Vector>"), Field->currentText());
 
   int i_c = KST::vectorList.count() + 1;
-  while (KST::dataTagNameNotUnique(tag_name, false)) {
+  while (KST::vectorTagNameNotUnique(tag_name, false)) {
     tag_name.sprintf("V%d-", i_c);
     tag_name += Field->currentText();
     i_c++;
@@ -256,6 +277,7 @@ void KstVectorDialogI::new_I() {
   emit vectorCreated(KstVectorPtr(vector));
   vector = 0L;
   vectorList.clear();
+  Select->setCurrentText(tag_name);
   emit modified();
 }
 
@@ -276,7 +298,9 @@ void KstVectorDialogI::edit_I() {
   } else {
     /* verify that the vector name is unique */
     if (Select->currentText() != vectorList[index]->tagName()) {
-      if (KST::dataTagNameNotUnique(Select->currentText())) return;
+      if (KST::vectorTagNameNotUnique(Select->currentText())) {
+        return;
+      }
     }
 
     /* if there is not an active KstFile, create one */
@@ -285,12 +309,12 @@ void KstVectorDialogI::edit_I() {
     if (it == KST::dataSourceList.end()) {
       file = KstDataSource::loadSource(FileName->url());
       if (!file || !file->isValid()) {
-	KMessageBox::sorry(0L, i18n("The file could not be opened."));
-	return;
+        KMessageBox::sorry(0L, i18n("The file could not be opened."));
+        return;
       }
       if (file->frameCount() < 1) {
-	KMessageBox::sorry(0L, i18n("The file does not contain data."));
-	return;
+        KMessageBox::sorry(0L, i18n("The file does not contain data."));
+        return;
       }
       KST::dataSourceList.append(file);
     } else {
@@ -306,14 +330,14 @@ void KstVectorDialogI::edit_I() {
 
     /* change the vector */
     vector->change(file, Field->currentText(),
-                   Select->currentText(),
-                   (CountFromEnd->isChecked() ?
-                    -1 : F0->value()),
-                   (ReadToEnd->isChecked() ?
-                    -1 : N->value()),
-                   Skip->value(),
-		   DoSkip->isChecked(),
-		   DoFilter->isChecked());
+        Select->currentText(),
+        (CountFromEnd->isChecked() ?
+         -1 : F0->value()),
+        (ReadToEnd->isChecked() ?
+         -1 : N->value()),
+        Skip->value(),
+        DoSkip->isChecked(),
+        DoFilter->isChecked());
 
     /** purge unused files */
     //doc->fileList.Purge();
@@ -356,3 +380,4 @@ void KstVectorDialogI::delete_I() {
 }
 
 #include "kstvectordialog_i.moc"
+// vim: sw=2 ts=2 et
