@@ -72,8 +72,14 @@ KstView::KstView(KstApp *parent, const char *name)
   /* initialize the popup menu */
   popupmenu = new KPopupMenu(this);
   QPopupMenu *submenu;
-  submenu = new KPopupMenu(this);
+
   _titleId = popupmenu->insertTitle(i18n("Plot"));
+
+  _matchMenu = new KPopupMenu(this);
+  _matchMenuId = popupmenu->insertItem(i18n("&Match Axis"), _matchMenu);
+  popupmenu->setItemEnabled(_matchMenuId, false);
+
+  submenu = new KPopupMenu(this);
   popupmenu->insertItem(i18n("Z&oom"), submenu);
   submenu->insertItem(i18n("Zoom &Maximum"), this, SLOT(zoomMaxSlot()), Key_M);
   submenu->insertItem(i18n("Zoom Max &Spike Insensitive"),
@@ -701,20 +707,21 @@ void KstView::mousePressEvent(QMouseEvent *e) {
         _addMenu->clear();
         _removeMenu->clear();
         _editCurveMenu->clear();
+        _matchMenu->clear();
         _currentPlot = p;
         int id = 100;
         bool addItemEnabled = false, removeItemEnabled = false;
         KstBaseCurveList curves = kstObjectSubList<KstDataObject, KstBaseCurve>(KST::dataObjectList);
-        for (KstBaseCurveList::Iterator i = curves.begin(); i != curves.end(); ++i) {
-          if (!p->Curves.contains((*i).data())) {
-            _addMenu->insertItem((*i)->tagName(), this, SLOT(dynamicMenuAdd(int)), 0, id);
+        for (KstBaseCurveList::Iterator it = curves.begin(); it != curves.end(); ++it) {
+          if (!p->Curves.contains((*it).data())) {
+            _addMenu->insertItem((*it)->tagName(), this, SLOT(dynamicMenuAdd(int)), 0, id);
             addItemEnabled = true;
           } else {
-            _removeMenu->insertItem((*i)->tagName(), this, SLOT(dynamicMenuRemove(int)), 0, id);
+            _removeMenu->insertItem((*it)->tagName(), this, SLOT(dynamicMenuRemove(int)), 0, id);
             removeItemEnabled = true;
-            _editCurveMenu->insertItem((*i)->tagName(), this, SLOT(dynamicMenuEdit(int)), 0, id);
+            _editCurveMenu->insertItem((*it)->tagName(), this, SLOT(dynamicMenuEdit(int)), 0, id);
           }
-          _curveIds[id] = (*i)->tagName();
+          _curveIds[id] = (*it)->tagName();
           ++id;
         }
 
@@ -722,6 +729,16 @@ void KstView::mousePressEvent(QMouseEvent *e) {
         popupmenu->setItemEnabled(_removeMenuId, removeItemEnabled);
         popupmenu->setItemEnabled(_editCurveMenuId, removeItemEnabled);
 
+        for (uint j = 0; j < KST::plotList.count(); ++j) {
+          if (j != i) {
+            _matchMenu->insertItem(KST::plotList.at(j)->tagName(), this, SLOT(dynamicMenuMatch(int)), 0, id);
+            // Yeah, we reuse _curveIds here
+            _curveIds[id] = KST::plotList.at(j)->tagName();
+            ++id;
+          }
+        }
+        popupmenu->setItemEnabled(_matchMenuId, KST::plotList.count() > 1);
+
         popupmenu->popup(mapToGlobal(e->pos()));
         return;
       }
@@ -1055,6 +1072,8 @@ void KstView::zoomOutSlot() {
   unsigned int count = KST::plotList.count();
   KstPlot *plot, *iplot;
 
+  if (count<1) return;
+
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   plot->getLScale(xmin, ymin, xmax, ymax);
 
@@ -1084,6 +1103,8 @@ void KstView::xzoomInSlot() {
   unsigned int count = KST::plotList.count();
   KstPlot *plot, *iplot;
 
+  if (count<1) return;
+
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   plot->getLScale(xmin, ymin, xmax, ymax);
 
@@ -1214,6 +1235,8 @@ void KstView::moveVertical(bool up) {
   unsigned int count = KST::plotList.count();
   KstPlot *plot, *iplot;
 
+  if (KST::plotList.count()<1) return;
+
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   plot->getLScale(xmin, ymin, xmax, ymax);
 
@@ -1267,6 +1290,8 @@ void KstView::moveHorizontal(bool left) {
   unsigned int count = KST::plotList.count();
   KstPlot *plot, *iplot;
 
+  if (count<1) return;
+
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   plot->getLScale(xmin, ymin, xmax, ymax);
 
@@ -1309,6 +1334,8 @@ void KstView::logSlot(bool x) {
   KstPlot *plot, *iplot;
   bool xLog, yLog;
 
+  if (count<1) return;
+
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   if (!plot) {
     return;
@@ -1416,6 +1443,24 @@ void KstView::dynamicMenuRemove(int id) {
    dynamicMenu(false, id);
 }
 
+void KstView::dynamicMenuMatch(int id) {
+  KstPlot *p = KST::plotList.FindKstPlot(_curveIds[id]);
+  if (p) {
+    double x0, x1, y0, y1;
+    p->getScale(x0, y0, x1, y1);
+    _currentPlot->setLog(p->isXLog(), p->isYLog());
+    _currentPlot->setXScaleMode(FIXED); //p->getXScaleMode());
+    _currentPlot->setYScaleMode(FIXED); //p->getYScaleMode());
+    _currentPlot->setXScale(x0, x1);
+    _currentPlot->setYScale(y0, y1);
+    _currentPlot->pushScale();
+    MouseInfo->setMode(INACTIVE);
+    needrecreate = true;
+    update();
+  }
+  _currentPlot = 0L;
+}
+
 void KstView::dynamicMenuEdit(int id) {
   KstDataObjectList::Iterator i = KST::dataObjectList.findTag(_curveIds[id]);
   if (i == KST::dataObjectList.end()) {
