@@ -53,6 +53,20 @@ const QString& Plugin::soFile() const {
 }
 
 
+int Plugin::call(const double *const inArrays[], const int inArrayLens[],
+                 const double inScalars[], double *outArrays[],
+                 int outArrayLens[], double outScalars[], void** local) const {
+  if (!_symbol || _data._filter) {
+    return CallError;
+  }
+
+  return ((int(*)(const double *const[], const int[],
+          const double[], double *[], int[],
+          double[], void**))_symbol)
+    (inArrays, inArrayLens, inScalars, outArrays, outArrayLens, outScalars, local);
+}
+
+
 int Plugin::call(const double *const inArrays[], const int inArrayLens[],
                  const double inScalars[], double *outArrays[],
                  int outArrayLens[], double outScalars[]) const {
@@ -61,8 +75,8 @@ int Plugin::call(const double *const inArrays[], const int inArrayLens[],
   }
 
   return ((int(*)(const double *const[], const int[],
-                  const double[], double *[], int[],
-                  double[]))_symbol)
+          const double[], double *[], int[],
+          double[]))_symbol)
     (inArrays, inArrayLens, inScalars, outArrays, outArrayLens, outScalars);
 }
 
@@ -78,6 +92,17 @@ int Plugin::filter(const double *const inArray, int inArrayLen,
 }
 
 
+int Plugin::filter(const double *const inArray, int inArrayLen,
+                 const double inScalars[], double *outArray[],
+                 int *outArrayLen, void **local) const {
+  if (!_symbol || !_data._filter) {
+    return CallError;
+  }
+
+  return ((int(*)(const double *const, int, const double[], double*[], int*, void**))_symbol) (inArray, inArrayLen, inScalars, outArray, outArrayLen, local);
+}
+
+
 const Plugin::Data& Plugin::data() const {
   return _data;
 }
@@ -86,6 +111,7 @@ const Plugin::Data& Plugin::data() const {
 
 void Plugin::Data::clear() {
   _filter = false;
+  _localdata = false;
   _name = QString::null;
   _author = QString::null;
   _description = QString::null;
