@@ -16,14 +16,16 @@
  ***************************************************************************/
 
 
+#include "kstdebug.h"
+#include "plugin.h"
 #include "plugincollection.h"
 #include "pluginloader.h"
 #include "pluginxmlparser.h"
-#include "plugin.h"
 
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klibloader.h>
+#include <klocale.h>
 #include <kstaticdeleter.h>
 #include <kstddirs.h>
 
@@ -241,14 +243,14 @@ void PluginCollection::scanPlugins() {
           backup.remove(_parser->data()._name);
         }
       } else {
-        kdDebug() << "Error parsing XML file " << *it + fi->fileName() << endl;
+        KstDebug::self()->log(i18n("Error parsing XML file '%1'.  Skipping.").arg(*it + fi->fileName()), KstDebug::Warning);
       }
       ++fit;
     }
   }
 
   while (!backup.isEmpty()) {
-    kdDebug() << "Detected disappearance of " << backup.begin().key() << endl;
+    KstDebug::self()->log(i18n("Detected disappearance of '%1'.").arg(backup.begin().key()));
     emit pluginRemoved(backup.begin().key());
     backup.remove(backup.begin());
     changed = true;
