@@ -16,12 +16,14 @@
  ***************************************************************************/
 
 
+#include "kstdebug.h"
 #include "pluginloader.h"
 #include "pluginxmlparser.h"
 
-#include <klibloader.h>
-#include <kstaticdeleter.h>
 #include <kdebug.h>
+#include <klibloader.h>
+#include <klocale.h>
+#include <kstaticdeleter.h>
 #include <qfile.h>
 #include <qregexp.h>
 
@@ -52,7 +54,7 @@ PluginLoader::~PluginLoader() {
 Plugin *PluginLoader::loadPlugin(const QString& xmlfile, const QString& object) {
   // First try to load the XML file.
   if (_parser->parseFile(xmlfile) != 0) {
-    kdDebug() << "Couldn't parse xml file " << xmlfile << "." << endl;
+    KstDebug::self()->log(i18n("Couldn't parse xml file '%1'.").arg(xmlfile), KstDebug::Error);
     return 0L;
   }
 
@@ -63,7 +65,7 @@ Plugin *PluginLoader::loadPlugin(const QString& xmlfile, const QString& object)
   // Load the plugin
   plug->_lib = KLibLoader::self()->library(object.local8Bit().data());
   if (!plug->_lib) {
-    kdDebug() << "Couldn't find library " << object << "." << endl;
+    KstDebug::self()->log(i18n("Couldn't find library '%1' while loading plugin.").arg(object), KstDebug::Error);
     delete plug;
     return 0L;
   }
@@ -71,7 +73,7 @@ Plugin *PluginLoader::loadPlugin(const QString& xmlfile, const QString& object)
   plug->_symbol = plug->_lib->symbol(plug->_data._name.latin1());
 
   if (!plug->_symbol) {
-    kdDebug() << "Couldn't find symbol " << plug->_data._name << " in plugin." << endl;
+    KstDebug::self()->log(i18n("Couldn't find symbol '%1' in plugin %2.").arg(plug->_data._name).arg(object), KstDebug::Error);
     delete plug;
     return 0L;
   }
